pub struct MockAccountsApi {
AccountsApi_expectations: MockAccountsApi_AccountsApi,
}Fields
AccountsApi_expectations: MockAccountsApi_AccountsApiImplementations
Sourceimpl MockAccountsApi
impl MockAccountsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAccountsApi
impl MockAccountsApi
Sourcepub fn expect_api_key(&mut self) -> &mut Expectation
pub fn expect_api_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the api_key method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_delete_sso_user(&mut self) -> &mut Expectation
pub fn expect_delete_sso_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_sso_user method
Sourcepub fn expect_get_account_revision_date(&mut self) -> &mut Expectation
pub fn expect_get_account_revision_date(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_account_revision_date method
Sourcepub fn expect_get_keys(&mut self) -> &mut Expectation
pub fn expect_get_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_keys method
Sourcepub fn expect_get_organizations(&mut self) -> &mut Expectation
pub fn expect_get_organizations(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organizations method
Sourcepub fn expect_get_profile(&mut self) -> &mut Expectation
pub fn expect_get_profile(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_profile method
Sourcepub fn expect_get_sso_user_identifier(&mut self) -> &mut Expectation
pub fn expect_get_sso_user_identifier(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_sso_user_identifier method
Sourcepub fn expect_get_subscription(&mut self) -> &mut Expectation
pub fn expect_get_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_subscription method
Sourcepub fn expect_post_cancel(&mut self) -> &mut Expectation
pub fn expect_post_cancel(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_cancel method
Sourcepub fn expect_post_delete_recover(&mut self) -> &mut Expectation
pub fn expect_post_delete_recover(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_delete_recover method
Sourcepub fn expect_post_delete_recover_token(&mut self) -> &mut Expectation
pub fn expect_post_delete_recover_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_delete_recover_token method
Sourcepub fn expect_post_email(&mut self) -> &mut Expectation
pub fn expect_post_email(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_email method
Sourcepub fn expect_post_email_token(&mut self) -> &mut Expectation
pub fn expect_post_email_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_email_token method
Sourcepub fn expect_post_kdf(&mut self) -> &mut Expectation
pub fn expect_post_kdf(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_kdf method
Sourcepub fn expect_post_keys(&mut self) -> &mut Expectation
pub fn expect_post_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_keys method
Sourcepub fn expect_post_license(&mut self) -> &mut Expectation
pub fn expect_post_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_license method
Sourcepub fn expect_post_password(&mut self) -> &mut Expectation
pub fn expect_post_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_password method
Sourcepub fn expect_post_password_hint(&mut self) -> &mut Expectation
pub fn expect_post_password_hint(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_password_hint method
Sourcepub fn expect_post_request_otp(&mut self) -> &mut Expectation
pub fn expect_post_request_otp(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_request_otp method
Sourcepub fn expect_post_security_stamp(&mut self) -> &mut Expectation
pub fn expect_post_security_stamp(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_security_stamp method
Sourcepub fn expect_post_set_password(&mut self) -> &mut Expectation
pub fn expect_post_set_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_set_password method
Sourcepub fn expect_post_verify_email(&mut self) -> &mut Expectation
pub fn expect_post_verify_email(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_verify_email method
Sourcepub fn expect_post_verify_email_token(&mut self) -> &mut Expectation
pub fn expect_post_verify_email_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_verify_email_token method
Sourcepub fn expect_post_verify_password(&mut self) -> &mut Expectation
pub fn expect_post_verify_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_verify_password method
Sourcepub fn expect_put_avatar(&mut self) -> &mut Expectation
pub fn expect_put_avatar(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_avatar method
Sourcepub fn expect_put_profile(&mut self) -> &mut Expectation
pub fn expect_put_profile(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_profile method
Sourcepub fn expect_put_update_tde_password(&mut self) -> &mut Expectation
pub fn expect_put_update_tde_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_update_tde_password method
Sourcepub fn expect_put_update_temp_password(&mut self) -> &mut Expectation
pub fn expect_put_update_temp_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_update_temp_password method
Sourcepub fn expect_resend_new_device_otp(&mut self) -> &mut Expectation
pub fn expect_resend_new_device_otp(&mut self) -> &mut Expectation
Create an Expectation for mocking the resend_new_device_otp method
Sourcepub fn expect_rotate_api_key(&mut self) -> &mut Expectation
pub fn expect_rotate_api_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the rotate_api_key method
Sourcepub fn expect_set_user_verify_devices(&mut self) -> &mut Expectation
pub fn expect_set_user_verify_devices(&mut self) -> &mut Expectation
Create an Expectation for mocking the set_user_verify_devices method
Sourcepub fn expect_verify_otp(&mut self) -> &mut Expectation
pub fn expect_verify_otp(&mut self) -> &mut Expectation
Create an Expectation for mocking the verify_otp method